# Optimizations

## Enumeration

```{eval-rst}
.. automodule:: ferrmion.optimize.enumeration
   :members:
   :undoc-members:
   :show-inheritance:
```

## Ternary Tree

```{eval-rst}
.. automodule:: ferrmion.optimize.topphatt
   :members:
   :undoc-members:
   :show-inheritance:
```
```{eval-rst}
.. automodule:: ferrmion.optimize.hatt
   :members:
   :undoc-members:
   :show-inheritance:
```
```{eval-rst}
.. automodule:: ferrmion.optimize.bonsai
   :members:
   :undoc-members:
   :show-inheritance:
```
```{eval-rst}
.. automodule:: ferrmion.optimize.rett
   :members:
   :undoc-members:
   :show-inheritance:
```
```{eval-rst}
.. automodule:: ferrmion.optimize.huffman
   :members:
   :undoc-members:
   :show-inheritance:
```
